==> solarus-0.9.0-src.tar.gz: solarus-0.9.0/include/entities/DynamicTile.h <==
/*
 * Copyright (C) 2009-2011 Christopho, Solarus - http://www.solarus-engine.org
 * 
 * Solarus is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Solarus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef SOLARUS_DYNAMIC_TILE_H
#define SOLARUS_DYNAMIC_TILE_H

#include "Common.h"
#include "entities/Detector.h"

/**
 * @brief A special tile that can be enabled or disabled.
 *
 * A dynamic tile is a tile placed on the map 
 * that can be enabled or disabled by the script,
 * contrary to the Tile instances that are totally static for performance reasons.
 * An enabled dynamic tile behaves like a normal tile and may be an obstacle.
 * A disabled dynamic tile is invisible and can be traversed.
 */
class DynamicTile: public Detector {

  private:

    int tile_pattern_id;       /**< id of the tile pattern */
    TilePattern *tile_pattern; /**< pattern of the tile */

  protected:

    bool test_collision_custom(MapEntity &entity);
    void notify_collision(MapEntity &entity_overlapping, CollisionMode collision_mode);

  public:

    DynamicTile(const std::string &name, Layer layer, int x, int y,
	int width, int height, int tile_pattern_id, bool visible);
    ~DynamicTile();
    static CreationFunction parse;

    EntityType get_type();
    void set_map(Map &map);
    bool is_obstacle_for(MapEntity &other);
    void display_on_map();
    void notify_enabled(bool enabled);
};

#endif

==> solarus-1.1.1-src.tar.gz: solarus-1.1.1/include/entities/DynamicTile.h <==
/*
 * Copyright (C) 2006-2013 Christopho, Solarus - http://www.solarus-games.org
 * 
 * Solarus is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Solarus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program. If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef SOLARUS_DYNAMIC_TILE_H
#define SOLARUS_DYNAMIC_TILE_H

#include "Common.h"
#include "entities/MapEntity.h"

/**
 * \brief A special tile that can be enabled or disabled.
 *
 * A dynamic tile is a tile placed on the map
 * that can be enabled or disabled by the script,
 * contrary to the Tile instances that are totally static for performance reasons.
 * An enabled dynamic tile behaves like a normal tile and may be an obstacle or any ground.
 * A disabled dynamic tile is invisible and can be traversed.
 */
class DynamicTile: public MapEntity {

  public:

    DynamicTile(const std::string& name, Layer layer, int x, int y,
	int width, int height, int tile_pattern_id, bool visible);
    ~DynamicTile();

    EntityType get_type() const;
    void set_map(Map& map);
    bool is_ground_modifier() const;
    Ground get_modified_ground() const;
    bool is_obstacle_for(MapEntity& other);
    void draw_on_map();

  private:

    int tile_pattern_id;       /**< id of the tile pattern */
    TilePattern* tile_pattern; /**< pattern of the tile */

};

#endif
